@@ -104,14 +104,19 @@ var searchData=
   ['jxlencoderuseboxes_101',['JxlEncoderUseBoxes',['../group__libjxl__encoder.html#ga667dae9b3d39cc1c859db1dddae47555',1,'encode.h']]],
   ['jxlencoderusecontainer_102',['JxlEncoderUseContainer',['../group__libjxl__encoder.html#ga3fbb30200bb9b55a550c01015f2bcb9c',1,'encode.h']]],
   ['jxlencoderversion_103',['JxlEncoderVersion',['../group__libjxl__encoder.html#gac2bc1706762bbd1c40fd06a41222156d',1,'encode.h']]],
-  ['jxlresizableparallelrunner_104',['JxlResizableParallelRunner',['../group__libjxl__threads.html#gad7cad7f1de97ddcd3868c678691365d5',1,'resizable_parallel_runner.h']]],
-  ['jxlresizableparallelrunnercreate_105',['JxlResizableParallelRunnerCreate',['../group__libjxl__threads.html#ga98a744fddf24168ff3efa7c10b8700a9',1,'resizable_parallel_runner.h']]],
-  ['jxlresizableparallelrunnerdestroy_106',['JxlResizableParallelRunnerDestroy',['../group__libjxl__threads.html#ga7f4055b9996895389107932ea17e2598',1,'resizable_parallel_runner.h']]],
-  ['jxlresizableparallelrunnersetthreads_107',['JxlResizableParallelRunnerSetThreads',['../group__libjxl__threads.html#gad9c22a8767f8ef655e997c5670436fc5',1,'resizable_parallel_runner.h']]],
-  ['jxlresizableparallelrunnersuggestthreads_108',['JxlResizableParallelRunnerSuggestThreads',['../group__libjxl__threads.html#gaa1c8b31a87c02d5d17f420b23d12d27b',1,'resizable_parallel_runner.h']]],
-  ['jxlsignaturecheck_109',['JxlSignatureCheck',['../group__libjxl__decoder.html#gae7c12395ee08066995b03efde8c3ba0d',1,'decode.h']]],
-  ['jxlthreadparallelrunner_110',['JxlThreadParallelRunner',['../group__libjxl__threads.html#ga37e181cb285bda4fb2978d035e58ff87',1,'thread_parallel_runner.h']]],
-  ['jxlthreadparallelrunnercreate_111',['JxlThreadParallelRunnerCreate',['../group__libjxl__threads.html#ga75346d2249a525594bb133c5e1b3cf8a',1,'thread_parallel_runner.h']]],
-  ['jxlthreadparallelrunnerdefaultnumworkerthreads_112',['JxlThreadParallelRunnerDefaultNumWorkerThreads',['../group__libjxl__threads.html#ga1705fa654dacb8b13d544628d702c31e',1,'thread_parallel_runner.h']]],
-  ['jxlthreadparallelrunnerdestroy_113',['JxlThreadParallelRunnerDestroy',['../group__libjxl__threads.html#ga8c782b85f63c04956637e100dd82ccdb',1,'thread_parallel_runner.h']]]
+  ['jxlgainmapgetbundlesize_104',['JxlGainMapGetBundleSize',['../group__libjxl__metadata.html#ga546a732f9f5891f66e7d72c62b6c118a',1,'gain_map.h']]],
+  ['jxlgainmapreadbundle_105',['JxlGainMapReadBundle',['../group__libjxl__metadata.html#ga69ce70bafe565a9bdfe7459e9727a19a',1,'gain_map.h']]],
+  ['jxlgainmapwritebundle_106',['JxlGainMapWriteBundle',['../group__libjxl__metadata.html#ga6843276a0ab8a7220e0a9ce1dc529213',1,'gain_map.h']]],
+  ['jxliccprofiledecode_107',['JxlICCProfileDecode',['../group__libjxl__metadata.html#ga0887d437a6f55ecb90937c7dfeb4b467',1,'compressed_icc.h']]],
+  ['jxliccprofileencode_108',['JxlICCProfileEncode',['../group__libjxl__metadata.html#ga81a828eb0538943000d66a5b6ebdf848',1,'compressed_icc.h']]],
+  ['jxlresizableparallelrunner_109',['JxlResizableParallelRunner',['../group__libjxl__threads.html#gad7cad7f1de97ddcd3868c678691365d5',1,'resizable_parallel_runner.h']]],
+  ['jxlresizableparallelrunnercreate_110',['JxlResizableParallelRunnerCreate',['../group__libjxl__threads.html#ga98a744fddf24168ff3efa7c10b8700a9',1,'resizable_parallel_runner.h']]],
+  ['jxlresizableparallelrunnerdestroy_111',['JxlResizableParallelRunnerDestroy',['../group__libjxl__threads.html#ga7f4055b9996895389107932ea17e2598',1,'resizable_parallel_runner.h']]],
+  ['jxlresizableparallelrunnersetthreads_112',['JxlResizableParallelRunnerSetThreads',['../group__libjxl__threads.html#gad9c22a8767f8ef655e997c5670436fc5',1,'resizable_parallel_runner.h']]],
+  ['jxlresizableparallelrunnersuggestthreads_113',['JxlResizableParallelRunnerSuggestThreads',['../group__libjxl__threads.html#gaa1c8b31a87c02d5d17f420b23d12d27b',1,'resizable_parallel_runner.h']]],
+  ['jxlsignaturecheck_114',['JxlSignatureCheck',['../group__libjxl__decoder.html#gae7c12395ee08066995b03efde8c3ba0d',1,'decode.h']]],
+  ['jxlthreadparallelrunner_115',['JxlThreadParallelRunner',['../group__libjxl__threads.html#ga37e181cb285bda4fb2978d035e58ff87',1,'thread_parallel_runner.h']]],
+  ['jxlthreadparallelrunnercreate_116',['JxlThreadParallelRunnerCreate',['../group__libjxl__threads.html#ga75346d2249a525594bb133c5e1b3cf8a',1,'thread_parallel_runner.h']]],
+  ['jxlthreadparallelrunnerdefaultnumworkerthreads_117',['JxlThreadParallelRunnerDefaultNumWorkerThreads',['../group__libjxl__threads.html#ga1705fa654dacb8b13d544628d702c31e',1,'thread_parallel_runner.h']]],
+  ['jxlthreadparallelrunnerdestroy_118',['JxlThreadParallelRunnerDestroy',['../group__libjxl__threads.html#ga8c782b85f63c04956637e100dd82ccdb',1,'thread_parallel_runner.h']]]
 ];
